/*
 *  ImgView  A simple image viewer
 *
 *  Copyright (C) 2013 Mats Peterson
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *  
 *  Please send any comments/bug reports to
 *  matsp888@yahoo.com  (Mats Peterson)
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include "imgview.h"

static void parse(char *s)
{
    char name[50], val[256], *p;

    memset(val, 0, sizeof(val));
    sscanf(s, "%s %255c", name, val);
    for (p = val + strlen(val) - 1; *p == ' ' || *p == '\t'; p--)
        *p = '\0';
    if (*val == '\0') {
        fprintf(stderr, "Invalid line `%s' in .imgviewrc\n", s);
        exit(1);
    }

    for (p = name; *p; p++) *p = (char)tolower((int)*p);

    if (! strcmp(name, "background_color"))
        strcpy(v.bgcolor_s, val);
    else if (! strcmp(name, "transparent_background_color"))
        strcpy(v.tbgcolor_s, val);
    else if (! strcmp(name, "bilevel_background_color"))
        strcpy(v.blbgcolor_s, val);
    else if (! strcmp(name, "bilevel_foreground_color"))
        strcpy(v.blfgcolor_s, val);
    else if (! strcmp(name, "rgb_profile"))
        strcpy(v.rgbprof, val);
    else if (! strcmp(name, "gray_profile"))
        strcpy(v.grayprof, val);
    else if (! strcmp(name, "cmyk_profile"))
        strcpy(v.cmykprof, val);
    else if (! strcmp(name, "output_profile"))
        strcpy(v.outprof, val);
    else if (! strcmp(name, "open_file_dialog_width"))
        v.odialogw = atoi(val);
    else if (! strcmp(name, "open_file_dialog_height"))
        v.odialogh = atoi(val);
}

void readconfig(FILE *f)
{
    char s[512];

    while (fgets(s, 512, f)) {
        s[strlen(s) - 1] = '\0';
        if (*s == '#' || *s == '\0') continue;
        parse(s);
    }
    fclose(f);
}
